#!/bin/ash
# sqlite3-places-5.sh # For use in terminal. # We gain half a second in execution time using
# ash rather than bash. Dash trips on some string manipulations; at line 26, for example.
#
# (c) Christian L'Écuyer, Gatineau (Qc), Canada, Aug. 8-9 2017. GPL3
#  (Alias « musher0 » [forum Puppy].) # https://opensource.org/licenses/GPL-3.0
#
# Usage :
# sqlite3-places-3.sh $1 # -=» for a specific search. # Replace "$1" with your search word.
# or
# sqlite3-places-3.sh # -=» to get a very short list (+/- 17) of URLs that you visited.
# Timeframe: this month and the month before (but see at line 49)
# ..................... AND the history duration you set in your browser.
#
#### set -xe
A="$1"

SQLitePlaces () { sqlite3 places.sqlite 'select url,last_visit_date from moz_places'; }

CleanUp () { rm -f Last*;rm -f breve.lst;
i="";for i in 2 3 4;do rm -f breve$i.lst;done; } # We keep breve5.lst as ref. in case of a bug.

SkimURLs () { >Last_100.output2;
while read total;do
	Long="`expr ${#total} - 6`" # # This simple math operation removes the milliseconds
	echo "${total:0:$Long}" >> Last_100.output2 # in the time field.
done < Last_100.output

sort -t\| -nk 2 Last_100.output2 | awk -F'\|' '$1 !~ /seamonkey|firefox|mozilla|mozdev|sex|porn|lesarch|google/ { print $0 }' | sort -t '|' -nk 2 -u > Last_100.tri3
# Sort on time field, excluding some thematics we don't care about. You may edit these thematics.

while read url;do
	if [ "${url:0:11}" = "http://www." ];then echo "${url:11:${#url}}" >> breve.lst
	elif [ "${url:0:12}" = "https://www." ];then echo "${url:12:${#url}}" >> /breve.lst
	elif [ "${url:0:7}" = "http://" ];then echo "${url:7:${#url}}" >> breve.lst
	elif [ "${url:0:8}" = "https://" ];then echo "${url:8:${#url}}" >> breve.lst
	elif [ "${url:0:4}" = "www." ];then echo "${url:4:${#url}}" >> breve.lst
	else echo "${url}" >> breve.lst
	fi
done < Last_100.tri3

> breve2.lst
while read result;do
	Total1="${result%|*}"
	Total1="`echo ${Total1} | awk -F'\/' '{print $3"/"$4 }'`" # For the sake of brevity,
	# we show only the main sites, not the pages visited within them.
	 [ "${Total1:0:4}" = "www." ] && Total1="${Total1#*.}"

	Total2="`date -d @${result#*|} +'%x'`" # %R: This is a summary, we consider the date only.
	Mois="`date +'%m'`"
	Mois="`expr $Mois - 2`" # Change 2 to 3 if you want to view 3 months back.
	[ "${Mois}" -lt "10" ] && Mois="0$Mois" # This zero is needed from January to September.

	echo "$Total1 § $Total2" | awk -F'-' '$(NF-1) > '$Mois' { print $0 }' >> breve2.lst # We retrieve
	# the browsing history from 2 months (absolute) back. Or 3 months (possible at line 49).
done < Last_100.tri3

for i in 2 3 4;do
	j="`expr $i + 1`"
	uniq -u breve$i.lst > breve$j.lst # We skim 3 times. # A plain sort would cancel the
done # previous time sort. Uniq is much better in this case. Some entries are repeated,
# but they tell the user something because the time sort is respected.

echo >> breve5.lst
cat breve5.lst >> /tmp/MZurls

CleanUp; }

echo > /tmp/MZurls # Action
ls -Algot /root/.*/*/*.default/places.sqlite | awk '{ print $NF }' > /tmp/MZplaces
while read place;do
	dir="`dirname $place`"
	echo "$dir" | awk -F'\/' '{ print "-- "$4" --" }' >> /tmp/MZurls # Name of browser
	cd "$dir"

	> breve.lst
	if [ -z $A ];then # If no positional parm., we work the whole URL field.
		SQLitePlaces | tail -n 130 | awk /http/ > Last_100.output
		SkimURLs

	else # If yes, we search only for the specified search word.
		SQLitePlaces | awk '$1 ~ /'$A'/' | awk /http/ > Last_100.output
		Lign="`wc -l < Last_100.output`"
		if [ "$Lign" -gt "3" ];then
			SkimURLs
			echo -e "entries for $A\n" >> /tmp/MZurls
			# We add the search word at the bottom df the list, to be clear.

		else
			echo -e "no entry for $A\n" >> /tmp/MZurls
			CleanUp
		fi
	fi
done < /tmp/MZplaces

more /tmp/MZurls # We show the list. # set +xe
## 30 ##
